@@ -216,14 +216,12 @@ async def job_get(request: sanic.request, job_id: str):
         return await sanic.response.file(result_file_path)
         # file_stream is slow ? bad chunk size ?
         # return await sanic.response.file_stream(result_file_path, chunked=False)
-    return sanic.response.HTTPResponse("Accepted", status=404)
+    return sanic.response.HTTPResponse("Not Found", status=404)
 
 
 if CONFIG["CIRCE_ENABLE_WEB_UI"]:
     cookie_signer = Signer(CONFIG["CIRCE_WEB_UI_CRYPT_KEY"])
-    server.static(
-        "/static/", os.path.dirname(os.path.abspath(__file__)) + "/static/"
-    )
+    server.static("/static/", os.path.dirname(os.path.abspath(__file__)) + "/static/")
 
     def _check_request_session(request: sanic.request) -> str:
         try:
